.. Stoq documentation master file, created by
   sphinx-quickstart on Fri Feb 10 16:50:57 2012.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Stoq's documentation!
================================

Contents:

.. toctree::
   :maxdepth: 4

   stoq


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

